@@ -5,7 +5,7 @@ assert_eq() {
     if ! diff -u <(echo "$1") <(echo "$2")
     then
         echo "expected values to be identical, but they're not"
-        exit 1
+        return 1
     fi
 }
 
@@ -14,6 +14,6 @@ assert_contains() {
     if ! echo "$1" | grep -F "$2" > /dev/null
     then
         echo "expected first value to contain second value"
-        exit 1
+        return 1
     fi
 }
