@@ -20,7 +20,7 @@ pub use error::SubplotError;
 pub mod resource;
 
 mod graphmarkup;
-pub use graphmarkup::{DotMarkup, GraphMarkup, PikchrMarkup, PlantumlMarkup};
+pub use graphmarkup::{DotMarkup, GraphMarkup, MarkupOpts, PikchrMarkup, PlantumlMarkup};
 
 mod datafiles;
 pub use datafiles::DataFile;
@@ -60,6 +60,7 @@ pub use parser::parse_scenario_snippet;
 mod matches;
 pub use matches::MatchedScenario;
 pub use matches::MatchedStep;
+pub use matches::MatchedSteps;
 pub use matches::PartialStep;
 pub use matches::StepSnippet;
 
